Third party libraries and references
====================================

Credit where credit is due; this page lists the key libraries used by
:brand:`tslumen` as well as research articles used as reference or inspiration.


Key Dependencies
-----------------
 - Pandas: https://pandas.pydata.org
 - NumPy: https://numpy.org
 - statsmodels: https://www.statsmodels.org
 - SciPy: https://www.scipy.org
 - SuperSmoother: https://github.com/jakevdp/supersmoother
 - Matplotlib: https://matplotlib.org
 - Networkx: https://networkx.org
 - Jinja: https://palletsprojects.com/p/jinja
 - Joblib: https://joblib.readthedocs.io
 - Hydra: https://hydra.cc
 - Plotly: https://plotly.com
 - Dash: https://dash.plotly.com
 - JupyterDash: https://github.com/plotly/jupyter-dash
 - Sphinx: https://www.sphinx-doc.org
 - Read the Docs: https://readthedocs.org


References
-----------
 - https://cran.r-project.org/package=tsfeatures
 - https://robjhyndman.com/papers/icdm2015.pdf
 - http://www.slac.stanford.edu/cgi-wrap/getdoc/slac-pub-3477.pdf
